@@ -1,10 +1,18 @@
-import os,sys
+#!/usr/bin/python3 
+
+
+import os
 from io import StringIO
-class csv2cleartable:
+import sys
+
+term_size = os.get_terminal_size()
+
+
+
+class csv2table:
     def printtable(self,message):
         #finalmessage=""
         #finalmessage=finalmessage +
-        term_size = os.get_terminal_size()
         print('=' * term_size.columns)
         flag=0
         for line in message.split('\n'):
@@ -13,7 +21,7 @@ class csv2cleartable:
         # print(line_list)
             line_list.append("End")
         #  print(line_list)
-    
+        
             for word in line_list:
                 if word == 'End':
                     print("\n")
@@ -25,14 +33,30 @@ class csv2cleartable:
                     print('{:>16}'.format(word),end ="|")
                 else:
                     print("\t\t\t",end =" ")
-            
+        
         print('=' * term_size.columns)
-            
+        
     def finalprinttable(self,message):
         old_stdout = sys.stdout
         new_stdout = StringIO()
         sys.stdout = new_stdout
+
         self.printtable(message)
+
         output = new_stdout.getvalue()
+
         sys.stdout = old_stdout
-        return output   
\ No newline at end of file
+
+        return output
+        
+
+
+def main():
+ ###
+    print("")
+
+    
+    
+
+if __name__ == '__main__':
+    main()
